
import "Turbine.Gameplay";
import "Turbine.UI.Extensions";
import "Turbine.Utils";

WEQuickslotWindow = class( Turbine.UI.Window );
--saferun( [[ --
function WEQuickslotWindow:Constructor(builderType, settings)
	Turbine.UI.Window.Constructor( self );

	self.settings = settings;
	self:SetPosition( self.settings.left, self.settings.top );
	self.gambitBuilder = builderType;
	self.spacing = 2;

	self.quickslotSize = 32;
	self.quickslots = { };

	self.player = Turbine.Gameplay.LocalPlayer();
	self.player.LevelChanged = function( sender, args )
		self:RefreshQuickslots();
	end

	self.PositionChanged = function( sender, args )
		self.settings.left, self.settings.top = self:GetPosition();
		self:SaveSettings();
	end

	self:RefreshQuickslots();

	self.DragBar = Deusdictum.UI.DragBar( self, self.gambitBuilder );
	self.DragBar:SetRotator( true );
	
	self:SetVisible( true );
	self:SetOpacity( 1 );
end

function WEQuickslotWindow:Rotate( args )
	self.settings.transposed = not self.settings.transposed;
	self:SaveSettings();
	self:RefreshQuickslots();
	self.DragBar:RecalculateSize();
end

function WEQuickslotWindow:SaveSettings()
	Deusdictum.Plugins.WardenEase.WEmain:SaveSettings();
end

function WEQuickslotWindow:RefreshQuickslots()
	local i, k, v;
	local lvl = self.player:GetLevel();

	self.gambits = {  };

	for k,v in pairs(Deusdictum.Data.Warden.Gambits) do
		if (v.Sequence[1].Builds == self.gambitBuilder and lvl >= v.Level) then
			table.insert(self.gambits, v);
		end
	end

	-- Remove any quickslots no longer required.
	for i = #(self.gambits) + 1, #(self.quickslots), 1 do
		self.quickslots[#(self.gambits) + 1]:SetVisible( false );
		self.quickslots[#(self.gambits) + 1]:SetParent( nil );
		table.remove(self.quickslots, #(self.gambits) + 1);
	end
	
	-- Add any new quickslots that should be created.
	for i = #(self.quickslots) + 1, #(self.gambits), 1 do
		self.quickslots[i] = Turbine.UI.Control();
		self.quickslots[i]:SetParent( self );
		self.quickslots[i]:SetSize( self.quickslotSize, self.quickslotSize );
		self.quickslots[i]:SetAllowDrop( false );
		self.quickslots[i]:SetBackground(self.gambits[i].Resource);
		self.quickslots[i].gambit = self.gambits[i];

		self.quickslots[i].MouseClick = function( sender, args )
			Deusdictum.Plugins.WardenEase.WEmain.builder = {};
			for i = 1, Deusdictum.Plugins.WardenEase.WEmain.maxGambitLength - #(sender.gambit.Sequence), 1 do
				Deusdictum.Plugins.WardenEase.WEmain.builder[i] = nil;
			end
			for i = Deusdictum.Plugins.WardenEase.WEmain.maxGambitLength - #(sender.gambit.Sequence) + 1, Deusdictum.Plugins.WardenEase.WEmain.maxGambitLength, 1 do
				Deusdictum.Plugins.WardenEase.WEmain.builder[i] = sender.gambit.Sequence[i + #(sender.gambit.Sequence) - Deusdictum.Plugins.WardenEase.WEmain.maxGambitLength];
			end
			Deusdictum.Plugins.WardenEase.WEmain:RefreshQuickslots();
		end
	end

	self:RefreshLayout();
end

function WEQuickslotWindow:pvar(tmp)
	Turbine.Shell.WriteLine(tmp);
end

function WEQuickslotWindow:RefreshLayout()
	local displayWidth = Turbine.UI.Display:GetWidth();
	local displayHeight = Turbine.UI.Display:GetHeight();

	self.slotsWide = 1;
	self.slotsHigh = #(self.gambits);

	if self.settings.transposed then
		self.slotsWide, self.slotsHigh = self.slotsHigh, self.slotsWide;
	end

	local i, width, height;

	width = self.slotsWide * (self.spacing + self.quickslotSize) - self.spacing;
	height = self.slotsHigh * (self.spacing + self.quickslotSize);

	self:SetSize(width, height)

	for i = 1, #(self.gambits), 1 do
		local col, row;

		col = (i - 1) % self.slotsWide;
		row = math.floor((i - 1) / self.slotsWide);
		self.quickslots[i]:SetPosition( col * (self.quickslotSize + self.spacing), row * (self.quickslotSize + self.spacing) );
	end
end
--]], "WEQuickslotWindow");